# Authors

Clay is written and maintained by the Lúcuma Team and various contributors.


Project Leader / Developer:

- Juan-Pablo Scaletti (jpscaletti / lucuma)


Contributors:

- przerull
- Muhammad Alkarouri (malkarouri)
- Alexander Zayats (z4y4ts)
